@@ -1,4 +1,4 @@
-__version__ = "0.2.5"
+__version__ = "0.2.7"
 
 from .auth import BasicAuth, TokenAuth  # noqa: F401
 from .entities import Dashboard  # noqa: F401
@@ -10,6 +10,7 @@ from .entities import (
     MostActiveUser,
     Project,
     ProjectUser,
+    ReportTimeEntry,
     Tag,
     Task,
     TimeEntry,
@@ -17,20 +18,20 @@ from .entities import (
     Workspace,
     WorkspaceUser,
 )
-from .repository import Projects  # noqa: F401
 from .repository import (
     Clients,
     Dashboards,
     Groups,
     ProjectUsers,
+    ReportTimeEntries,
     Tags,
-    Tasks,
     TimeEntries,
     Users,
     Workspaces,
     WorkspaceUsers,
 )
 
+
 __all__ = [
     "Activity",
     "BasicAuth",
@@ -43,13 +44,13 @@ __all__ = [
     "Groups",
     "MostActiveUser",
     "Project",
-    "Projects",
     "ProjectUser",
     "ProjectUsers",
+    "ReportTimeEntry",
+    "ReportTimeEntries",
     "Tag",
     "Tags",
     "Task",
-    "Tasks",
     "TimeEntries",
     "TimeEntry",
     "TokenAuth",
